==> vtigercrm-5.2.1p2.tgz: modules/Faq/language/es_es.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.

 ********************************************************************************
*  Module       : Faq
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30 Last change : 2007-10-10
*  Author       : Rafael Soler
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME' => 'FAQ',
'LBL_MODULE_TITLE'=>'FAQ: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar FAQ',
'LBL_LIST_FORM_TITLE'=>'Lista de FAQ',
'LBL_NEW_FORM_TITLE'=>'Nueva Faq',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Organizaciones Miembro',

'LBL_LIST_ACCOUNT_NAME'=>'Faq',
'LBL_LIST_CITY'=>'Población',
'LBL_LIST_WEBSITE'=>'Página Web',
'LBL_LIST_STATE'=>'Provincia',
'LBL_LIST_PHONE'=>'Teléfono',
'LBL_LIST_EMAIL_ADDRESS'=>'Dirección de Email',
'LBL_LIST_CONTACT_NAME'=>'Persona de Contacto',
'LBL_FAQ_INFORMATION'=>'Información de FAQ',

//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',

//END DON'T CONVERT

'LBL_ACCOUNT'=>'Faq:',
'LBL_ACCOUNT_NAME'=>'Faq:',
'LBL_PHONE'=>'Teléfono:',
'LBL_WEBSITE'=>'Página Web:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Ticker de bolsa:',
'LBL_OTHER_PHONE'=>'Tel. Directo:',
'LBL_ANY_PHONE'=>'Tel. Adicional:',
'LBL_MEMBER_OF'=>'Miembro de:',
'LBL_EMAIL'=>'Email:',
'LBL_EMPLOYEES'=>'Empleados:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Email (Otro):',
'LBL_ANY_EMAIL'=>'Email (Alternativo):',
'LBL_OWNERSHIP'=>'Propietario:',
'LBL_RATING'=>'Clasificación:',
'LBL_INDUSTRY'=>'Actividad:',
'LBL_SIC_CODE'=>'CIF:',
'LBL_TYPE'=>'Tipo:',
'LBL_ANNUAL_REVENUE'=>'Facturación Anual:',
'LBL_ADDRESS_INFORMATION'=>'Información de la Dirección',
'LBL_ACCOUNT_INFORMATION'=>'Informaciaón de Faq',
'LBL_BILLING_ADDRESS'=>'Dirección (Factura):',
'LBL_SHIPPING_ADDRESS'=>'Dirección (Envío):',
'LBL_ANY_ADDRESS'=>'Dirección (Alternativa):',
'LBL_CITY'=>'Población:',
'LBL_STATE'=>'Provincia:',
'LBL_POSTAL_CODE'=>'Código Postal:',
'LBL_COUNTRY'=>'País:',
'LBL_DESCRIPTION_INFORMATION'=>'Información adicional',
'LBL_DESCRIPTION'=>'Descripción:',
'NTC_COPY_BILLING_ADDRESS'=>'Copiar Factura a Envío',
'NTC_COPY_SHIPPING_ADDRESS'=>'Copiar Envío a Factura',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'¿Está seguro que desea eliminar este registro como miembro de organización?',
'LBL_DUPLICATE'=>'Posible Faq duplicada',
'MSG_DUPLICATE'=>'Al crear esta Faq puede crear una Faq duplicada. Puede seleccionar una Faq de la lista inferior o hacer pinchar en \"Crea FAQ Nuevo\" para crear una nueva FAQ con los datos introducidos.',

'LBL_INVITEE'=>'Contactos',
'ERR_DELETE_RECORD'=>'Debe especificar un registro para poder eliminar la FAQ.',

'LBL_SELECT_ACCOUNT'=>'Seleccionar Faq',
'LBL_GENERAL_INFORMATION'=>'Información General',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nueva Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidad',

'LBL_NEW_TASK'=>'Nueva Tarea',
'LBL_TASK_TITLE'=>'Tarea',
'LBL_NEW_CALL'=>'Nueva Llamada',
'LBL_CALL_TITLE'=>'Llamadas',
'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',
'LBL_NEW_EMAIL'=>'Nuevo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_CONTACT'=>'Nuevo Contacto',
'LBL_CONTACT_TITLE'=>'Contactos',

//Added for 4GA Release
'Category'=>'Categoría',
'Related To'=>'Relacionado con',
'Question'=>'Pregunta',
'Answer'=>'Respuesta',
'Comments'=>'Comentarios',
'LBL_COMMENTS'=>'Comentarios',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Fecha de Modificación',

//Added vtiger_fields after 4.2 alpha
'LBL_TICKETS'=>'Partes',
'LBL_FAQ'=>'FAQ',
'Product Name'=>'Nombre del Producto',
'FAQ Id'=>'Número de FAQ',
'Add Comment'=>'Añadir Comentario',
'LBL_ADD_COMMENT'=>'Añadir Comentario',
'LBL_COMMENT_INFORMATION'=>'Información del Comentario',
'Status'=>'Estado',

//Added on 10-12-2005
'LBL_QUESTION'=>'Pregunta',
'LBL_CATEGORY'=>'Categoría',
'LBL_MY_FAQ'=>'Mis FAQs Recientes',

//Added for existing Picklist Entries

'General'=>'General',

'Draft'=>'Borrador',
'Reviewed'=>'Revisada',
'Published'=>'Publicada',
'Obsolete'=>'Obsoleta',

// Module Sequence Numbering
'Faq No' => 'Núm. FAQ',
// END

);

?>

==> vtigercrm-5.3.0p0.tgz: modules/Faq/language/es_es.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.

 ********************************************************************************
*  Module       : Faq
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30 Last change : 2007-10-10
*  Author       : Rafael Soler
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME' => 'FAQ',
'LBL_MODULE_TITLE'=>'FAQ: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar FAQ',
'LBL_LIST_FORM_TITLE'=>'Lista de FAQ',
'LBL_NEW_FORM_TITLE'=>'Nueva Faq',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Organizaciones Miembro',

'LBL_LIST_ACCOUNT_NAME'=>'Faq',
'LBL_LIST_CITY'=>'Población',
'LBL_LIST_WEBSITE'=>'Página Web',
'LBL_LIST_STATE'=>'Provincia',
'LBL_LIST_PHONE'=>'Teléfono',
'LBL_LIST_EMAIL_ADDRESS'=>'Dirección de Email',
'LBL_LIST_CONTACT_NAME'=>'Persona de Contacto',
'LBL_FAQ_INFORMATION'=>'Información de FAQ',

//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',

//END DON'T CONVERT

'LBL_ACCOUNT'=>'Faq:',
'LBL_ACCOUNT_NAME'=>'Faq:',
'LBL_PHONE'=>'Teléfono:',
'LBL_WEBSITE'=>'Página Web:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Ticker de bolsa:',
'LBL_OTHER_PHONE'=>'Tel. Directo:',
'LBL_ANY_PHONE'=>'Tel. Adicional:',
'LBL_MEMBER_OF'=>'Miembro de:',
'LBL_EMAIL'=>'Email:',
'LBL_EMPLOYEES'=>'Empleados:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Email (Otro):',
'LBL_ANY_EMAIL'=>'Email (Alternativo):',
'LBL_OWNERSHIP'=>'Propietario:',
'LBL_RATING'=>'Clasificación:',
'LBL_INDUSTRY'=>'Actividad:',
'LBL_SIC_CODE'=>'CIF:',
'LBL_TYPE'=>'Tipo:',
'LBL_ANNUAL_REVENUE'=>'Facturación Anual:',
'LBL_ADDRESS_INFORMATION'=>'Información de la Dirección',
'LBL_ACCOUNT_INFORMATION'=>'Informaciaón de Faq',
'LBL_BILLING_ADDRESS'=>'Dirección (Factura):',
'LBL_SHIPPING_ADDRESS'=>'Dirección (Envío):',
'LBL_ANY_ADDRESS'=>'Dirección (Alternativa):',
'LBL_CITY'=>'Población:',
'LBL_STATE'=>'Provincia:',
'LBL_POSTAL_CODE'=>'Código Postal:',
'LBL_COUNTRY'=>'País:',
'LBL_DESCRIPTION_INFORMATION'=>'Información adicional',
'LBL_DESCRIPTION'=>'Descripción:',
'NTC_COPY_BILLING_ADDRESS'=>'Copiar Factura a Envío',
'NTC_COPY_SHIPPING_ADDRESS'=>'Copiar Envío a Factura',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'¿Está seguro que desea eliminar este registro como miembro de organización?',
'LBL_DUPLICATE'=>'Posible Faq duplicada',
'MSG_DUPLICATE'=>'Al crear esta Faq puede crear una Faq duplicada. Puede seleccionar una Faq de la lista inferior o hacer pinchar en "Crea FAQ Nuevo" para crear una nueva FAQ con los datos introducidos.',

'LBL_INVITEE'=>'Contactos',
'ERR_DELETE_RECORD'=>'Debe especificar un registro para poder eliminar la FAQ.',

'LBL_SELECT_ACCOUNT'=>'Seleccionar Faq',
'LBL_GENERAL_INFORMATION'=>'Información General',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nueva Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidad',

'LBL_NEW_TASK'=>'Nueva Tarea',
'LBL_TASK_TITLE'=>'Tarea',
'LBL_NEW_CALL'=>'Nueva Llamada',
'LBL_CALL_TITLE'=>'Llamadas',
'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',
'LBL_NEW_EMAIL'=>'Nuevo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_CONTACT'=>'Nuevo Contacto',
'LBL_CONTACT_TITLE'=>'Contactos',

//Added for 4GA Release
'Category'=>'Categoría',
'Related To'=>'Relacionado con',
'Question'=>'Pregunta',
'Answer'=>'Respuesta',
'Comments'=>'Comentarios',
'LBL_COMMENTS'=>'Comentarios',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Fecha de Modificación',

//Added vtiger_fields after 4.2 alpha
'LBL_TICKETS'=>'Partes',
'LBL_FAQ'=>'FAQ',
'Product Name'=>'Nombre del Producto',
'FAQ Id'=>'Número de FAQ',
'Add Comment'=>'Añadir Comentario',
'LBL_ADD_COMMENT'=>'Añadir Comentario',
'LBL_COMMENT_INFORMATION'=>'Información del Comentario',
'Status'=>'Estado',

//Added on 10-12-2005
'LBL_QUESTION'=>'Pregunta',
'LBL_CATEGORY'=>'Categoría',
'LBL_MY_FAQ'=>'Mis FAQs Recientes',

//Added for existing Picklist Entries

'General'=>'General',

'Draft'=>'Borrador',
'Reviewed'=>'Revisada',
'Published'=>'Publicada',
'Obsolete'=>'Obsoleta',

// Module Sequence Numbering
'Faq No' => 'Núm. FAQ',
// END

);

?>
